@@ -6,6 +6,7 @@ from concurrent.futures import ThreadPoolExecutor
 from scipy.interpolate import RegularGridInterpolator
 import torch
 import numpy as np
+import re
 
 
 def reshape_field(field,factor):
@@ -213,6 +214,23 @@ def getPattern(pathFile):
     except Exception as e:
         print(f"Error reading pattern from file: {e}")
         return None
+    
+def detect_space_0_and_space_1(hex_string):
+    binary_string = bin(int(hex_string, 16))[2:].zfill(len(hex_string) * 4)
+
+    # On cherche un motif de type 0^n 1^m répété plusieurs fois
+    for size in range(4, len(binary_string) // 2):
+        unit = binary_string[:size]
+        if re.fullmatch(r'0+1+', unit):
+            # Vérifier si ce motif est répété
+            repeat_count = len(binary_string) // len(unit)
+            repeated = (unit * repeat_count)[:len(binary_string)]
+            if repeated == binary_string:
+                space_0 = unit.find("1")
+                space_1 = len(unit) - space_0
+                return space_0, space_1
+
+    raise ValueError("Motif de type 0^n 1^m non trouvé dans l'hexadécimal.")
 
 def getAngle(pathFile):
     """
